summaryrefslogtreecommitdiffstats
path: root/lib/kformula/indexelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/indexelement.h')
-rw-r--r--lib/kformula/indexelement.h118
1 files changed, 59 insertions, 59 deletions
diff --git a/lib/kformula/indexelement.h b/lib/kformula/indexelement.h
index 06aac43d..49b03bc7 100644
--- a/lib/kformula/indexelement.h
+++ b/lib/kformula/indexelement.h
@@ -35,7 +35,7 @@ class IndexElement : public BasicElement {
IndexElement& operator=( const IndexElement& ) { return *this; }
public:
- IndexElement(BasicElement* parent = 0);
+ IndexElement(BasicElement* tqparent = 0);
~IndexElement();
IndexElement( const IndexElement& );
@@ -49,9 +49,9 @@ public:
/**
* @returns the character that represents this element. Used for
* parsing a sequence.
* This is guaranteed to be QChar::null for all non-text elements.
*/
- virtual QChar getCharacter() const;
+ virtual TQChar getCharacter() const;
/**
* The cursor has entered one of our child sequences.
@@ -66,7 +66,7 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
// drawing
//
@@ -77,7 +77,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -85,19 +85,19 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
@@ -137,7 +137,7 @@ public:
*/
virtual void moveDown(FormulaCursor* cursor, BasicElement* from);
- // children
+ // tqchildren
/**
* Removes the child. If this was the main child this element might
@@ -151,7 +151,7 @@ public:
// main child
//
- // If an element has children one has to become the main one.
+ // If an element has tqchildren one has to become the main one.
virtual SequenceElement* getMainChild() { return content; }
//SequenceElement* upperLeft;
@@ -163,7 +163,7 @@ public:
/**
- * Inserts all new children at the cursor position. Places the
+ * Inserts all new tqchildren at the cursor position. Places the
* cursor according to the direction.
*
* You only can insert one index at a time. So the list must contain
@@ -172,11 +172,11 @@ public:
*
* The list will be emptied but stays the property of the caller.
*/
- virtual void insert(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void insert(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
- * Removes all selected children and returns them. Places the
- * cursor to where the children have been.
+ * Removes all selected tqchildren and returns them. Places the
+ * cursor to where the tqchildren have been.
*
* The cursor has to be inside one of our indexes which is supposed
* to be empty. The index will be removed and the cursor will
@@ -185,7 +185,7 @@ public:
*
* The ownership of the list is passed to the caller.
*/
- virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
* Moves the cursor to a normal place where new elements
@@ -212,7 +212,7 @@ public:
/**
* Returns wether the element has no more useful
- * children (except its main child) and should therefore
+ * tqchildren (except its main child) and should therefore
* be replaced by its main child's content.
*/
virtual bool isSenseless();
@@ -259,12 +259,12 @@ public:
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
// the upper right index is the only one we show
- virtual QString formulaString();
+ virtual TQString formulaString();
protected:
@@ -273,39 +273,39 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "INDEX"; }
+ virtual TQString getTagName() const { return "INDEX"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
- virtual QString getElementName() const ;
- virtual void writeMathMLAttributes( QDomElement& element ) const ;
- virtual void writeMathMLContent( QDomDocument& doc,
- QDomElement& element,
+ virtual TQString getElementName() const ;
+ virtual void writeMathMLAttributes( TQDomElement& element ) const ;
+ virtual void writeMathMLContent( TQDomDocument& doc,
+ TQDomElement& element,
bool oasisFormat ) const ;
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
- virtual bool readAttributesFromMathMLDom( const QDomElement& element );
+ virtual bool readAttributesFromMathMLDom( const TQDomElement& element );
/**
* Reads our content from the MathML node. Sets the node to the next node
* that needs to be read. It is sometimes needed to read more than one node
* (e. g. for fence operators).
* Returns the number of nodes processed or -1 if it failed.
*/
- virtual int readContentFromMathMLDom( QDomNode& node );
+ virtual int readContentFromMathMLDom( TQDomNode& node );
private:
@@ -314,78 +314,78 @@ private:
*/
class IndexElementIndex : public ElementIndex {
public:
- IndexElementIndex(IndexElement* p) : parent(p) {}
- virtual IndexElement* getElement() { return parent; }
+ IndexElementIndex(IndexElement* p) : tqparent(p) {}
+ virtual IndexElement* getElement() { return tqparent; }
protected:
- IndexElement* parent;
+ IndexElement* tqparent;
};
// We have a (very simple) type for every index.
class UpperLeftIndex : public IndexElementIndex {
public:
- UpperLeftIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ UpperLeftIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToUpperLeft(cursor, direction); }
+ { tqparent->moveToUpperLeft(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToUpperLeft(cursor); }
+ { tqparent->setToUpperLeft(cursor); }
virtual bool hasIndex() const
- { return parent->hasUpperLeft(); }
+ { return tqparent->hasUpperLeft(); }
};
class LowerLeftIndex : public IndexElementIndex {
public:
- LowerLeftIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ LowerLeftIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToLowerLeft(cursor, direction); }
+ { tqparent->moveToLowerLeft(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToLowerLeft(cursor); }
+ { tqparent->setToLowerLeft(cursor); }
virtual bool hasIndex() const
- { return parent->hasLowerLeft(); }
+ { return tqparent->hasLowerLeft(); }
};
class UpperMiddleIndex : public IndexElementIndex {
public:
- UpperMiddleIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ UpperMiddleIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToUpperMiddle(cursor, direction); }
+ { tqparent->moveToUpperMiddle(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToUpperMiddle(cursor); }
+ { tqparent->setToUpperMiddle(cursor); }
virtual bool hasIndex() const
- { return parent->hasUpperMiddle(); }
+ { return tqparent->hasUpperMiddle(); }
};
class LowerMiddleIndex : public IndexElementIndex {
public:
- LowerMiddleIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ LowerMiddleIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToLowerMiddle(cursor, direction); }
+ { tqparent->moveToLowerMiddle(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToLowerMiddle(cursor); }
+ { tqparent->setToLowerMiddle(cursor); }
virtual bool hasIndex() const
- { return parent->hasLowerMiddle(); }
+ { return tqparent->hasLowerMiddle(); }
};
class UpperRightIndex : public IndexElementIndex {
public:
- UpperRightIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ UpperRightIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToUpperRight(cursor, direction); }
+ { tqparent->moveToUpperRight(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToUpperRight(cursor); }
+ { tqparent->setToUpperRight(cursor); }
virtual bool hasIndex() const
- { return parent->hasUpperRight(); }
+ { return tqparent->hasUpperRight(); }
};
class LowerRightIndex : public IndexElementIndex {
public:
- LowerRightIndex(IndexElement* parent) : IndexElementIndex(parent) {}
+ LowerRightIndex(IndexElement* tqparent) : IndexElementIndex(tqparent) {}
virtual void moveToIndex(FormulaCursor* cursor, Direction direction)
- { parent->moveToLowerRight(cursor, direction); }
+ { tqparent->moveToLowerRight(cursor, direction); }
virtual void setToIndex(FormulaCursor* cursor)
- { parent->setToLowerRight(cursor); }
+ { tqparent->setToLowerRight(cursor); }
virtual bool hasIndex() const
- { return parent->hasLowerRight(); }
+ { return tqparent->hasLowerRight(); }
};
@@ -49,9 +49,9 @@ public:
* @returns the character that represents this element. Used for
* parsing a sequence.
- * This is guaranteed to be QChar::null for all non-text elements.
+ * This is guaranteed to be TQChar::null for all non-text elements.
*/
@@ -85,19 +85,19 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/